local ArenaMatchUpdater = ArenaHistory.ArenaMatchUpdater
local Logger = ArenaHistory.Logger
local UI = ArenaHistory.UI

ArenaHistory.VERSION = 3

ArenaHistory.logger = Logger.new("ArenaHistory")
ArenaHistory.db = {}

function ArenaHistory:OnInitialize()
  self.logger:debug("onInitialize")
  self.db = LibStub("AceDB-3.0"):New("ArenaHistoryDB")
  if self.db.global.games_raw == nil then
    self.db.global.games_raw = {}
  end
end

function ArenaHistory:OnEnable()
  self.logger:debug("onEnable")
  
  self:RegisterChatCommand("arenahistory", "OnChatCommand")
  self:RegisterChatCommand("ah", "OnChatCommand")
  self:RegisterMessage("ARENA_HISTORY_ARENA_MATCH_RECORDED")

  ArenaMatchUpdater:OnEnable(ArenaHistory.VERSION)
end

function ArenaHistory:ARENA_HISTORY_ARENA_MATCH_RECORDED(event, match)
  self.logger:info("Arena ended. Result: %d", match.score or 255)
  table.insert(self.db.global.games_raw, 1, match)
end

function ArenaHistory:getMatchesCount()
  if self.db.global == nil or self.db.global.games_raw == nil then
    return 0
  end
  return table.getn(self.db.global.games_raw)
end

function ArenaHistory:getMatch(num)
  if num < 1 or num >= self:getMatchesCount() then
    return nil
  end
  return self.db.global.games_raw[num]
end

function ArenaHistory:OnChatCommand()
  UI:toggle()
end
