ArenaHistory.Filter = {}
local Filter = ArenaHistory.Filter
Filter.__index = Filter

local AceEvent = LibStub:GetLibrary("AceEvent-3.0")
AceEvent:Embed(Filter)

function Filter.new(condition)
  local self = setmetatable({}, Filter)
  self:RegisterMessage("ARENA_HISTORY_ARENA_MATCH_RECORDED",
      function(event, game)
        self:onNewGame(game)
      end)
  self.condition = condition
  self.cache = {}
  self.last_checked = 0
  self.have_in_cache = 0
  return self
end

function Filter:dispose()
  self.cache = nil
  self:UnregisterMessage("ARENA_HISTORY_ARENA_MATCH_RECORDED")
end

function Filter:onNewGame(game)
  if game ~= nil and self.condition(game) then
    table.insert(self.cache, 1, game)
    self.have_in_cache = self.have_in_cache + 1
  end
  self.last_checked = self.last_checked + 1
end

function Filter:updateCache(to)
  while (self.last_checked < ArenaHistory:getMatchesCount() and
      self.have_in_cache < to) do
    self.last_checked = self.last_checked + 1
    local game = ArenaHistory:getMatch(self.last_checked)
    if game ~= nil and self.condition(game) then
      self.have_in_cache = self.have_in_cache + 1
      self.cache[self.have_in_cache] = game 
    end
  end
end

function Filter:getGame(i)
  self:updateCache(i)
  return self.cache[i]
end

function Filter:getCount(extra)
  local totalMatches = ArenaHistory:getMatchesCount() 
  if self.last_checked == totalMatches then
    return self.have_in_cache
  else
    return self.have_in_cache + extra
  end
end
